@@ -1,14 +1,14 @@
-# Copyrights 2007-2021 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2024 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution Log-Report. Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Log::Report::Dispatcher;
 use vars '$VERSION';
-$VERSION = '1.33';
+$VERSION = '1.39';
 
 
 use warnings;
@@ -16,7 +16,7 @@ use strict;
 
 use Log::Report 'log-report';
 use Log::Report::Util qw/parse_locale expand_reasons %reason_code
-  escape_chars/;
+  escape_chars use_errno/;
 
 use POSIX      qw/strerror/;
 use List::Util qw/sum first/;
@@ -186,7 +186,7 @@ sub translate($$$)
         if $locale && $locale ne $oldloc;
 
     my $r = $self->{format_reason}->((__$reason)->toString);
-    my $e = $opts->{errno} ? strerror($opts->{errno}) : undef;
+    my $e = use_errno($reason) ? strerror($opts->{errno} || 1) : undef;
 
     my $format
       = $r && $e ? N__"{reason}: {message}; {error}"
