@@ -1,14 +1,14 @@
-# Copyrights 2007-2018 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2024 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution Log-Report. Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Log::Report::Message;
 use vars '$VERSION';
-$VERSION = '1.27';
+$VERSION = '1.39';
 
 
 use warnings;
@@ -113,6 +113,12 @@ sub to(;$)
 }
 
 
+sub errno(;$)
+{	my $self = shift;
+	@_ ? $self->{_errno} = shift : $self->{_errno};
+}
+
+
 sub valueOf($) { $_[0]->{$_[1]} }
 
 #--------------
